import decodeFuncType from "./decode";
import encodeFuncType from "./encode";

export const decode: decodeFuncType;
export const parse: decodeFuncType;

export const encode: encodeFuncType;
export const stringify: encodeFuncType;
